:py:mod:`piel.models.physical.electro_optic.basic_heater`
=========================================================

.. py:module:: piel.models.physical.electro_optic.basic_heater


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.physical.electro_optic.basic_heater.basic_heater_spice



.. py:function:: basic_heater_spice()

   This function returns the most basic SPICE model for a heater, that can be closely integrated with circuit solvers accordingly.
